# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/pl_PL/__init__.py

person_formats_pl_pl = c(
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{prefixes}} {{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{prefixes}} {{first_names}} {{last_names}}'
)

person_first_names_male_pl_pl = c(
  "Jakub",
  "Jan",
  "Mateusz",
  "Bartek",
  "Kacper",
  "Micha\u0142",
  "Szymon",
  "Antoni",
  "Filip",
  "Piotr",
  "Maciej",
  "Aleksander",
  "Franciszek",
  "Miko\u0142aj",
  "Adam",
  "Stanis\u0142aw",
  "Wiktor",
  "Krzysztof",
  "Wojciech",
  "Igor",
  "Maksymilian",
  "Karol",
  "Dawid",
  "Tomasz",
  "Patryk",
  "Oskar",
  "Pawe\u0142",
  "Dominik",
  "Kamil",
  "Oliwier",
  "Ignacy",
  "Marcel",
  "Hubert",
  "Adrian",
  "\u0141ukasz",
  "Sebastian",
  "Julian",
  "Tymon",
  "Krystian",
  "Marcin",
  "Damian",
  "Mi\u0142osz",
  "Leon",
  "Alan",
  "Tymoteusz",
  "Kajetan",
  "Grzegorz",
  "Daniel",
  "Rafa\u0142",
  "Eryk",
  "Konrad",
  "Ksawery",
  "Gabriel",
  "Nikodem",
  "Bruno",
  "Przemys\u0142aw",
  "Borys",
  "Artur",
  "Olaf",
  "Jerzy",
  "Marek",
  "Tadeusz",
  "Andrzej",
  "Witold",
  "Iwo",
  "Juliusz",
  "Robert",
  "B\u0142a\u017cej",
  "Cezary",
  "Jeremi",
  "Jacek",
  "Konstanty",
  "Ryszard",
  "Stefan",
  "Aleks",
  "Gustaw",
  "Rados\u0142aw",
  "Emil",
  "Norbert",
  "Fabian",
  "J\u0119drzej",
  "Alex",
  "Kazimierz",
  "Arkadiusz",
  "Kornel",
  "J\u00f3zef",
  "Natan",
  "Cyprian",
  "Mieszko",
  "Nataniel",
  "Maks",
  "Maurycy",
  "Olgierd",
  "Dariusz",
  "Leonard",
  "Mariusz",
  "Albert",
  "Fryderyk",
  "Ernest",
  "Tobiasz"
)

person_first_names_female_pl_pl = c(
  "Kamila",
  "Ewa",
  "Blanka",
  "Olga",
  "Kalina",
  "Klara",
  "Urszula",
  "Sandra",
  "Kaja",
  "Marianna",
  "Kornelia",
  "Justyna",
  "Monika",
  "Sara",
  "Adrianna",
  "Aniela",
  "Agnieszka",
  "R\u00f3\u017ca",
  "Marcelina",
  "Roksana",
  "Natasza",
  "Lidia",
  "Malwina",
  "Karina",
  "Ada",
  "Marika",
  "Anastazja",
  "Sonia",
  "Nela",
  "Dorota",
  "Apolonia",
  "Ida",
  "Eliza",
  "Angelika",
  "Anna Maria",
  "Liwia",
  "Ewelina",
  "Julita",
  "Rozalia",
  "Inga",
  "Krystyna",
  "Bianka",
  "Dagmara",
  "Melania",
  "Sylwia",
  "Nicole",
  "Anita",
  "Aurelia",
  "El\u017cbieta",
  "Janina",
  "Julianna",
  "Tola",
  "Gaja"
)

person_unisex_last_names_pl_pl = c(
  "Wandzel",
  "Pajda",
  "Dzienis",
  "Borysewicz",
  "Szlaga",
  "Krzysiek",
  "Iwa\u0144czyk",
  "Cierpisz",
  "Borczyk",
  "Szymula",
  "Pietrasiak",
  "Minkiewicz",
  "Hojka",
  "Goral",
  "Sta\u015b",
  "Smoter",
  "Bosek",
  "Bitner",
  "Kondej",
  "Furga\u0142",
  "Durlik",
  "Kusa",
  "Pacewicz",
  "Masiak",
  "Kucz",
  "Cichowlas",
  "Anders",
  "Wawszczak",
  "S\u0142upek",
  "Pych",
  "Piszcz",
  "Opoka",
  "Lorenz",
  "Grochowina",
  "Wicha",
  "Pawliczek",
  "Kus",
  "Zysk",
  "Sroga",
  "Rychel",
  "Patora",
  "Maciocha",
  "Rozmiarek",
  "Pesta",
  "Dzia\u0142ak",
  "Gody\u0144",
  "Chmara",
  "Jakubaszek",
  "Ba\u0142azy",
  "Ryka\u0142a",
  "Wika",
  "Kotala",
  "Fikus",
  "Sus",
  "Kunc",
  "Mateusiak",
  "Kusyk",
  "Roma\u0144czyk",
  "Makie\u0142a",
  "Lejman",
  "Ko\u0142aczek",
  "Kurzak",
  "Bondyra",
  "Podkowa",
  "Pa\u015bnik",
  "Oleszko",
  "Marcol",
  "Szybiak",
  "Ruszczak",
  "Zbroja",
  "Stosik",
  "Gruchot",
  "Bo\u015b",
  "Wo\u017cniak",
  "Gniewek",
  "Bu\u0142awa",
  "Wiatrak",
  "Tala\u015bka",
  "Patalas",
  "Kwoka",
  "Krzempek",
  "Danilczuk",
  "Wa\u017cny",
  "Sidorczuk",
  "Legutko",
  "Kobos",
  "Tylek",
  "Szkoda",
  "Przerwa",
  "Linek",
  "Galik",
  "Dulewicz",
  "Drozda",
  "Nowek",
  "Matulewicz",
  "Karpeta",
  "Jurczuk",
  "Bu\u015bko",
  "S\u0142omian",
  "Drywa",
  "Rybus",
  "Langa",
  "Kluczek",
  "Orkisz",
  "Ziemkiewicz",
  "Siara",
  "Para",
  "Kwasek",
  "Januszko",
  "Hejduk",
  "\u0141uszczak",
  "Sprawka",
  "Kie\u0142ek",
  "Jop",
  "Faryna",
  "Zimo\u0144",
  "Utrata",
  "Mirga",
  "Kozaczuk",
  "Wojtyna",
  "Rzo\u0144ca",
  "Madejczyk",
  "Glapiak",
  "Dziadkowiec",
  "Ochnio",
  "Sieja",
  "Malewicz",
  "Bachanek",
  "Mirocha",
  "Dom\u017ca\u0142",
  "Tworzyd\u0142o",
  "P\u0142aneta",
  "Feret",
  "Witas",
  "Figat",
  "Muc",
  "Kuciel",
  "Kielan",
  "Ha\u0142at",
  "Tec\u0142aw",
  "Loba",
  "Klucznik",
  "Bielas",
  "Rajczyk",
  "Myszak",
  "Muniak",
  "Michalczak",
  "Kochanowicz",
  "Szo\u0142tysik",
  "Rychert",
  "Pyda",
  "Janowiak",
  "Janiga",
  "Gr\u0105dziel",
  "Wdowczyk",
  "Pytlarz",
  "Kuzia",
  "Dziewa",
  "Bernatowicz",
  "Ostapiuk",
  "Rejniak",
  "Kotlarek",
  "Gajownik",
  "Brach",
  "Tatarek",
  "Szyc",
  "Masny",
  "Drop",
  "Saternus",
  "Podsiad\u0142a",
  "Patyna",
  "Kargol",
  "Truchan",
  "Pietrusiak",
  "Kolbusz",
  "Kalota",
  "Ho\u0142ubowicz",
  "Andrzejuk",
  "Zdziech",
  "Szymonik",
  "Sych",
  "Strojna",
  "Seta",
  "Orman",
  "Hermanowicz",
  "Denkiewicz",
  "Bulanda",
  "Szwaja",
  "Jankowicz",
  "Pochopie\u0144",
  "Kobza",
  "Karwot",
  "Ka\u0142ek",
  "Laszuk",
  "Aleksiejuk",
  "Witaszek",
  "Wawryniuk",
  "Jacak",
  "Bugla",
  "Wejman",
  "Jaroch",
  "Janiszek",
  "Gorzela\u0144czyk",
  "Zieja",
  "Krochmal",
  "Filas",
  "Wawrzynowicz",
  "Sza\u0142as",
  "Macho\u0144",
  "Labus",
  "Irzyk",
  "Gomu\u0142a",
  "Weso\u0142y",
  "Solarek",
  "Ko\u015bka",
  "Myszk",
  "Moryc",
  "Lizo\u0144",
  "Lesisz",
  "Kie\u0142bowicz",
  "Serwa",
  "Pi\u00f3rek",
  "Majdak",
  "Bruzda",
  "Bakun",
  "Subocz",
  "Stypu\u0142a",
  "Go\u0142ek",
  "Fik",
  "Wo\u0142czyk",
  "Waniek",
  "Parzyszek",
  "Oszust",
  "Burza",
  "\u017bbik",
  "Misztela",
  "Kurant",
  "Drygas",
  "\u0141aciak",
  "Franczuk",
  "Rycerz",
  "\u017bok",
  "Zeman",
  "Mejer",
  "Kanarek",
  "J\u0119druch",
  "Saj",
  "Nieroda",
  "Ju\u015bkiewicz",
  "Surdyk",
  "Paliga",
  "Makaruk",
  "Hamera",
  "\u0141ukowicz",
  "Barcz",
  "Witos",
  "Strzelczak",
  "Siedlaczek",
  "Pakosz",
  "Burchardt",
  "Nurek",
  "Morys",
  "Korbel",
  "Kokosza",
  "Kijanka",
  "Bobak",
  "Samson",
  "Jarosiewicz",
  "Szelest",
  "Stanis\u0142awek",
  "Perka",
  "Ciep\u0142uch",
  "Bryja",
  "\u015awi\u0105tkiewicz",
  "Samul",
  "Rohde",
  "Prucnal",
  "Miszkiewicz",
  "Kuropatwa",
  "Gajdzik",
  "Mu\u0107ka",
  "Misiaszek",
  "Fornalik",
  "Wiszowaty",
  "Thiel",
  "Osiadacz",
  "Mi\u015bko",
  "Mielcarz",
  "Dr\u00f3zd",
  "Oleksiuk",
  "Matyka",
  "\u0141yczak",
  "Caba\u0142a",
  "O\u015bka",
  "Bere\u015b",
  "Armatys",
  "Szmajda",
  "M\u0142y\u0144czak",
  "Kupidura",
  "Kijas",
  "Chomiuk",
  "Gowin",
  "Dybka",
  "Br\u00f3dka",
  "Wzi\u0105tek",
  "\u015al\u0119czka",
  "Koj",
  "Drabczyk",
  "Buczko",
  "Sawko",
  "K\u0142ysz",
  "Karpiel",
  "Jarczyk",
  "Flaga",
  "Fiedorczuk",
  "Tomalak",
  "Na\u0142\u0119cz",
  "Choro\u015b",
  "Bra\u0144ka",
  "Rajchel",
  "Kiedrowicz",
  "G\u0105bka",
  "Fio\u0142ek",
  "Drozdowicz",
  "Stypa",
  "Kawala",
  "Mazanek",
  "Kwinta",
  "Koczy",
  "Hy\u017cy",
  "Grzejszczak",
  "Wywia\u0142",
  "Sacharczuk",
  "Jaroszuk",
  "Golon",
  "Chachu\u0142a",
  "Malarczyk",
  "Kawula",
  "Bohdanowicz",
  "Bartocha",
  "Lewko",
  "Igras",
  "Damps",
  "Tla\u0142ka",
  "Niechcia\u0142",
  "\u0141yskawa",
  "Go\u015b",
  "Wi\u0119ckiewicz",
  "Le\u015bko",
  "Konsek",
  "Juszczuk",
  "Szczud\u0142o",
  "Poniedzia\u0142ek",
  "Palus",
  "Bodziony",
  "\u015amieszek",
  "Rej",
  "Pietryga",
  "Miesza\u0142a",
  "Malcher",
  "Kopij",
  "Kaczan",
  "Janasik",
  "Watras",
  "Stojak",
  "Strzy\u017c",
  "Siemieniec",
  "Ko\u015bnik",
  "Kasperczak",
  "Woszczyna",
  "Wiech",
  "Stefanik",
  "Miara",
  "\u0141odyga",
  "Walo",
  "Oleksiewicz",
  "Mainka",
  "Baka",
  "Trybu\u015b",
  "Samol",
  "Jamro\u017cy",
  "Gruszczyk",
  "Deluga",
  "Trzos",
  "Sinkiewicz",
  "Lesik",
  "Kroczak",
  "Klamka",
  "Grzelczyk",
  "Dycha",
  "Ciesielczyk",
  "Armata",
  "Wawrzyczek",
  "Prokopczyk",
  "Hampel",
  "Grzech",
  "Rzucid\u0142o",
  "Rawa",
  "Kr\u0119cisz",
  "Kary\u015b",
  "Rodze\u0144",
  "Karalus",
  "Mikosz",
  "Kazimierczuk",
  "Hajda",
  "Berg",
  "Teper",
  "S\u0142abosz",
  "Dziechciarz",
  "Dmoch",
  "\u015aleziak",
  "Pietrek",
  "Martyka",
  "Wo\u0142k",
  "Sm\u0119tek",
  "Kroll",
  "Grab",
  "Dziedzina",
  "Noszczyk",
  "Kazek",
  "J\u0119drusiak",
  "Cebo",
  "Tokarek",
  "Ma\u0142ota",
  "Hanc",
  "Uliasz",
  "Pysz",
  "Pi\u0142ka",
  "B\u0142aszyk",
  "Wyrobek",
  "Trybus",
  "Szl\u0119k",
  "Pindor",
  "\u0141uc",
  "Baszak",
  "Majak",
  "\u0141\u00f3j",
  "Szczypek",
  "\u0141uczkiewicz",
  "\u0141aszcz",
  "Fro\u0144",
  "Dyba\u015b",
  "Budner",
  "Ostasz",
  "Siekierka",
  "Pilipczuk",
  "Kandzia",
  "Giero\u0144",
  "Drost",
  "Chwa\u0142a",
  "Malesza",
  "Fiedler",
  "Suszko",
  "Kurnik",
  "Bereda",
  "Nalewajko",
  "Duczmal",
  "Sieradzan",
  "Pietrasz",
  "Cecot",
  "Tomaszkiewicz",
  "Rabiej",
  "Staniaszek",
  "Mikusek",
  "Kury\u0142owicz",
  "Herda",
  "Brzykcy",
  "Pocz\u0105tek",
  "Ochal",
  "Koral",
  "Ka\u017amierczyk",
  "Kandziora",
  "Sycz",
  "Reich",
  "Lindner",
  "Fulara",
  "Przybycie\u0144",
  "Hermann",
  "Forysiak",
  "Strz\u0119pek",
  "Sondej",
  "Py\u0107",
  "Pia\u015bcik",
  "Grygo",
  "Wita",
  "Szynkiewicz",
  "Piesik",
  "Nasiadka",
  "Murach",
  "Kostro",
  "Hinca",
  "Engler",
  "Tu\u0142acz",
  "Przewo\u017any",
  "Pizo\u0144",
  "\u0141apacz",
  "Hajduga",
  "Bulczak",
  "Bubel",
  "Smutek",
  "Samoraj",
  "Plaskota",
  "Fra\u015b",
  "Becker",
  "Baranowicz",
  "Trznadel",
  "Topa",
  "Stanis\u0142awczyk",
  "Lato",
  "Ko\u0142ton",
  "Uryga",
  "Tomaszczyk",
  "Szymanik",
  "Stochmal",
  "Kiszczak",
  "Dylong",
  "Chruszcz",
  "Byra",
  "Friedrich",
  "Cyganik",
  "Pacocha",
  "Jonczyk",
  "Szyma\u0144czyk",
  "Radko",
  "Meler",
  "Kuran",
  "Koman",
  "B\u0142\u0105dek",
  "Banachowicz",
  "Babiuch",
  "Kruszka",
  "Fijo\u0142",
  "Zato\u0144",
  "W\u0142odarz",
  "Trepka",
  "\u015awierszcz",
  "Strza\u0142a",
  "Opio\u0142a",
  "Kursa",
  "Dy\u015b",
  "Bro\u015b",
  "Tyka",
  "Syroka",
  "Grys",
  "Szczepaniuk",
  "Marci\u0144czyk",
  "Leks",
  "Kubina",
  "Janke",
  "D\u0105browicz",
  "Hulb\u00f3j",
  "Cieciura",
  "Choch\u00f3\u0142",
  "Szpila",
  "Samiec",
  "Rduch",
  "Nabia\u0142ek",
  "Margol",
  "Kopa",
  "Engel",
  "Czerepak",
  "Ros\u0142on",
  "Pusz",
  "Matla",
  "Wo\u0142och",
  "Pazik",
  "Nazimek",
  "Ku\u015bka",
  "Karczmarz",
  "Gajzler",
  "S\u0142awik",
  "Lalak",
  "Grabias",
  "G\u0105ga\u0142a",
  "Chwedoruk",
  "Wasil",
  "Pacho\u0142ek",
  "Wich\u0142acz",
  "Walentynowicz",
  "Tylus",
  "Kosz",
  "Iwanow",
  "Garczarek",
  "Dorociak",
  "Boguta",
  "Betka",
  "Widuch",
  "Wawrzynek",
  "Szymajda",
  "Stanaszek",
  "Klama",
  "Goj",
  "Dzier\u017cak",
  "Walasik",
  "Skwira",
  "Luks",
  "Kujawiak",
  "Dworczak",
  "Tofil",
  "Rurarz",
  "Pachla",
  "Lenarcik",
  "Kusztal",
  "Chaber",
  "Ska\u0142a",
  "Radzewicz",
  "Kramer",
  "Kochel",
  "Dukat",
  "Naglik",
  "Szurek",
  "Litwiniuk",
  "Halama",
  "Grzela",
  "Wojaczek",
  "Popielarczyk",
  "Krysik",
  "Dawidczyk",
  "Barteczko",
  "Balik",
  "Warych",
  "Miodek",
  "Madera",
  "Leszczyk",
  "Kolanek",
  "Fijak",
  "Furga\u0142a",
  "Faruga",
  "Poleszak",
  "Kusek",
  "Herok",
  "Golda",
  "Rymarz",
  "Pociask",
  "Kowalak",
  "Czupryna",
  "Trzcionka",
  "Sulik",
  "Matulka",
  "Herbut",
  "Stosio",
  "Kurtyka",
  "Ciuk",
  "Szczerbiak",
  "Snoch",
  "Budniak",
  "Boruc",
  "Tylka",
  "Kwak",
  "Garncarz",
  "Szuta",
  "Mi\u015bkowiec",
  "Sykut",
  "Jarosik",
  "Golus",
  "Chmielak",
  "Abramczuk",
  "Skrobek",
  "Patrza\u0142ek",
  "Linkiewicz",
  "Jereczek",
  "Jarema",
  "Flasza",
  "Fiedoruk",
  "Budkiewicz",
  "\u015awigo\u0144",
  "Przewo\u017anik",
  "Parada",
  "Heller",
  "Gierak",
  "Ferdyn",
  "Sumera",
  "Bik",
  "Kamela",
  "Ciereszko",
  "\u015awitaj",
  "Pastuszko",
  "\u0141obacz",
  "Kuba",
  "Krzywonos",
  "Granat",
  "Sz\u00f3stak",
  "P\u0142oskonka",
  "Kumorek",
  "Komuda",
  "Klinkosz",
  "Falba",
  "Szczechowicz",
  "Rozum",
  "Moro\u0144",
  "Matynia",
  "Greszta",
  "\u0141uczka",
  "Dziewit",
  "Mueller",
  "Kapral",
  "Hrynkiewicz",
  "Gonsior",
  "Forma",
  "Ciesi\u00f3\u0142ka",
  "Bors",
  "Siwa",
  "Niemczuk",
  "Nazar",
  "Li\u015bkiewicz",
  "Jarczak",
  "Felisiak",
  "Fedorczyk",
  "Wilusz",
  "Pastor",
  "Gierek",
  "Romaniak",
  "Oleszczak",
  "Juras",
  "Zachwieja",
  "Szmur\u0142o",
  "Smekta\u0142a",
  "Przewo\u017ana",
  "Nikel",
  "Chlebek",
  "Balas",
  "Latuszek",
  "Ambrozik",
  "Janczura",
  "Aleksandrzak",
  "Wojtalik",
  "Rok",
  "Nag\u00f3rka",
  "Latoszek",
  "Kubowicz",
  "Domian",
  "Ciemi\u0119ga",
  "Soliwoda",
  "Komsta",
  "Filus",
  "Wierzcho\u0144",
  "Skotarczak",
  "Cader",
  "Trzmiel",
  "Jagie\u0142o",
  "Wawszczyk",
  "Tro\u0107",
  "Swatek",
  "B\u0105czkiewicz",
  "Ulewicz",
  "Tutka",
  "Pa\u0142ac",
  "Mydlarz",
  "Molka",
  "Janiuk",
  "Guziak",
  "Frycz",
  "Drza\u0142",
  "Zacharek",
  "Wiencek",
  "Sz\u0142apka",
  "Kurach",
  "Bareja",
  "Pawlukiewicz",
  "Mo\u017adzierz",
  "Mich",
  "Lisik",
  "Ka\u0142wa",
  "Dadej",
  "Matela",
  "Lenda",
  "Wolff",
  "Wojnicz",
  "Sendor",
  "Mr\u00f3zek",
  "\u0141\u0105giewka",
  "Kulisz",
  "Kolarz",
  "Walus",
  "Mikoda",
  "Kral",
  "Darul",
  "Warczak",
  "Kunysz",
  "Kido\u0144",
  "Ciu\u0142a",
  "Chomiak",
  "Rze\u017aniczak",
  "Przenios\u0142o",
  "Chomik",
  "Zimol\u0105g",
  "Wojty\u015b",
  "M\u0119drala",
  "Hennig",
  "Handzel",
  "Twardzik",
  "\u015amieja",
  "Solarczyk",
  "Mendak",
  "Lemieszek",
  "Kiryluk",
  "Wrze\u015bniak",
  "Kwarciak",
  "Gasik",
  "Borysiewicz",
  "Sierota",
  "Mysiak",
  "Kraszkiewicz",
  "Hyjek",
  "Polaszek",
  "Pazera",
  "Kubisz",
  "Ko\u015bciukiewicz",
  "Kopczyk",
  "Kliber",
  "Kaczmar",
  "Kaczka",
  "Bicz",
  "Augustynek",
  "Straszak",
  "Sajewicz",
  "Glanc",
  "Bzymek",
  "Zieniewicz",
  "Pagacz",
  "Gortat",
  "Bubak",
  "Warwas",
  "Skoneczna",
  "Nestorowicz",
  "Dziopa",
  "Danisz",
  "Bazyd\u0142o",
  "Garncarek",
  "Albin",
  "Szeszko",
  "Naczk",
  "\u0141ukowiak",
  "Kopciuch",
  "Jakoniuk",
  "W\u0119grzynowicz",
  "Walencik",
  "Turlej",
  "Leonowicz",
  "Kierepka",
  "Hendzel",
  "Fronczek",
  "Zarzeczna",
  "Zagrodnik",
  "Wa\u0142\u0119sa",
  "Trzepizur",
  "Tereszkiewicz",
  "Szczube\u0142ek",
  "Magier",
  "Dzia\u0142o",
  "Dryga\u0142a",
  "Czesak",
  "Majorek",
  "Wliz\u0142o",
  "Skutnik",
  "Radke",
  "Pi\u0105tkiewicz",
  "O\u015bliz\u0142o",
  "Kansy",
  "Szela",
  "Mol",
  "Ku\u015bwik",
  "Karpik",
  "Janczarek",
  "Hajdukiewicz",
  "Mzyk",
  "Kostera",
  "Leszkiewicz",
  "Hutnik",
  "Glaza",
  "Fydrych",
  "Piegza",
  "Matusewicz",
  "Matus",
  "Kluczyk",
  "Drobnik",
  "Po\u0142om",
  "Okraska",
  "Neska",
  "Koz\u0142owicz",
  "Wo\u0142os",
  "Wac\u0142awczyk",
  "Ochnik",
  "Maruszczak",
  "Lesner",
  "Kuncewicz",
  "Kieszek",
  "Betlej",
  "Wa\u0142doch",
  "Szarejko",
  "Smalec",
  "\u0141osiewicz",
  "Lisak",
  "Walkusz",
  "Owsiak",
  "Kowaluk",
  "Simon",
  "Rup",
  "Neubauer",
  "Muska\u0142a",
  "Kucharzyk",
  "Gabryel",
  "Zimniak",
  "Warmuz",
  "Opas",
  "Michniak",
  "Cieloch",
  "W\u00f3jcikiewicz",
  "\u015awiech",
  "Powier\u017ca",
  "Olko",
  "Mi\u0119kus",
  "Kutnik",
  "Kustosz",
  "Kochman",
  "Tr\u0105bka",
  "Szyja",
  "M\u0142ynarz",
  "Wojtak",
  "Dzierwa",
  "Zygu\u0142a",
  "Taciak",
  "Koziatek",
  "Koss",
  "Walenciak",
  "Twardosz",
  "Pakos",
  "Mamcarz",
  "Burzawa",
  "Lenik",
  "Franc",
  "Sadza",
  "M\u0105drzak",
  "Mak",
  "Bobel",
  "Szajna",
  "Proch",
  "Kosela",
  "Gu\u017aniczak",
  "Radziewicz",
  "Olchawa",
  "Morcinek",
  "Bastek",
  "Ragan",
  "Podeszwa",
  "Mitek",
  "Janoszka",
  "S\u0142aba",
  "Rusnak",
  "P\u0142\u00f3cienniczak",
  "Hanke",
  "Gosek",
  "Wujek",
  "Warcha\u0142",
  "Starzak",
  "Prochownik",
  "Molak",
  "Duszkiewicz",
  "Sztaba",
  "Piwek",
  "Nowotnik",
  "Kiljan",
  "Dubel",
  "Brodowicz",
  "Tylec",
  "Pik",
  "Pastucha",
  "Ksi\u0119\u017cak",
  "Gumieniak",
  "Ufnal",
  "Stawinoga",
  "S\u0142o\u0144",
  "Kolarczyk",
  "John",
  "Fleszar",
  "Lemke",
  "Kurc",
  "Kamieniarz",
  "Jask\u00f3\u0142a",
  "Jaremko",
  "Gogacz",
  "Duda\u0142a",
  "Chlipa\u0142a",
  "Sz\u0142apa",
  "Seidel",
  "Kopyt",
  "Kar\u0142owicz",
  "G\u0119bura",
  "Fr\u0105czkiewicz",
  "Frankowicz",
  "Dybiec",
  "Drobny",
  "Br\u00f3zda",
  "Boru\u0144",
  "Pelka",
  "Macias",
  "Ruszel",
  "Pabis",
  "Krefta",
  "\u0106wierz",
  "Biele\u0144",
  "Szyca",
  "Pronobis",
  "Dreszer",
  "Bryzek",
  "Ambro\u017cewicz",
  "S\u0142obodzian",
  "Mrozowicz",
  "Wojak",
  "Szklarek",
  "Paw",
  "Ko\u015bcielak",
  "Kalarus",
  "Wylega\u0142a",
  "Pow\u0105zka",
  "M\u0142ot",
  "Krekora",
  "Bilewicz",
  "Pyszka",
  "Nied\u017awiadek",
  "Lubera",
  "Chodak",
  "Bregu\u0142a",
  "Synak",
  "Supe\u0142",
  "Suda",
  "Roczniak",
  "Matuszyk",
  "Helak",
  "Gubernat",
  "Wojtera",
  "Wiszowata",
  "\u015awi\u0119to\u0144",
  "Dery\u0142o",
  "Sza\u0142aj",
  "Rzeszutko",
  "Matejczuk",
  "\u017bo\u0142\u0105d\u017a",
  "Suchta",
  "Pokrzywa",
  "Pigu\u0142a",
  "Litwi\u0144czuk",
  "Kik",
  "Gula",
  "Geisler",
  "Mica\u0142",
  "Maszota",
  "Kurzyna",
  "Feliksiak",
  "Cybul",
  "Wiaderek",
  "\u015anieg",
  "Linka",
  "Fidler",
  "Fabiszak",
  "Cibor",
  "Ryczko",
  "Rudolf",
  "J\u0119drzejek",
  "Bekus",
  "Bek",
  "Wolan",
  "Radzio",
  "Kuliberda",
  "Kolanko",
  "Szyku\u0142a",
  "Skowyra",
  "Porwo\u0142",
  "Kosiak",
  "Kasica",
  "Jakiel",
  "Piejko",
  "Owczarczak",
  "Michnik",
  "Linke",
  "Kutera",
  "Bobryk",
  "Szabla",
  "Powa\u0142a",
  "Marciniszyn",
  "Gorgol",
  "Czerwionka",
  "Ledzion",
  "Dykas",
  "Zygmuntowicz",
  "Listwan",
  "Bobrowicz",
  "\u017burawik",
  "Miga\u0142a",
  "Merchel",
  "Bogumi\u0142",
  "Wojsa",
  "Sadura",
  "\u0141yjak",
  "Giers",
  "Ga\u0142at",
  "Parafiniuk",
  "Kryszkiewicz",
  "Wyrostek",
  "Wa\u0142ek",
  "Rembisz",
  "Pa\u015bciak",
  "Maksym",
  "Kusio",
  "Kostek",
  "Kalisiak",
  "B\u017adziuch",
  "Szlufik",
  "Pogorzelec",
  "Pielech",
  "Kafel",
  "Gmur",
  "Glazer",
  "Borysiuk",
  "Bia\u0142k",
  "Adamaszek",
  "Wiesio\u0142ek",
  "Waku\u0142a",
  "Rogula",
  "Leszczuk",
  "Kapciak",
  "Gul",
  "Buszka",
  "Sklorz",
  "Parda",
  "Miszkiel",
  "Latek",
  "Kurzyd\u0142o",
  "Kucharz",
  "Giec",
  "Wajdzik",
  "Mazik",
  "Klimko",
  "Kleina",
  "Dorawa",
  "Perczak",
  "Lang",
  "Grunt",
  "Cywka",
  "Bat\u00f3g",
  "Wid\u0142ak",
  "Miszta",
  "Ko\u015b\u0107",
  "Kosid\u0142o",
  "Aleksander",
  "Marchlewicz",
  "Korkosz",
  "Be\u015bka",
  "Bak",
  "Stoch",
  "Makles",
  "Hudzik",
  "Hornik",
  "Bujko",
  "Zi\u0119tal",
  "Zawal",
  "Sochaj",
  "Podpora",
  "Ma\u0142yszek",
  "Ma\u0107k\u00f3w",
  "Latacz",
  "Kozdra",
  "Kosno",
  "Gog\u00f3\u0142",
  "Fit",
  "Bienia",
  "Wendt",
  "Szyda",
  "Sucho\u0144",
  "Sobel",
  "Lesiewicz",
  "Kole\u015bnik",
  "Kinder",
  "Kasper",
  "Jaszczyszyn",
  "Weremczuk",
  "Steinke",
  "S\u0105dej",
  "Pu\u0142a",
  "Nowrot",
  "Nowotny",
  "Majorczyk",
  "Kunert",
  "Jerzyk",
  "Capa\u0142a",
  "Barto\u015b",
  "Wojciech",
  "Stelmasiak",
  "Portka",
  "Pietrak",
  "\u0141uksza",
  "Kulma",
  "Jeske",
  "G\u00f3raj",
  "Fyda",
  "Siemion",
  "Rusiniak",
  "Flisiak",
  "Cherek",
  "Bryndza",
  "Zio\u0142a",
  "Zapa\u015bnik",
  "Raszkiewicz",
  "Pszcz\u00f3\u0142ka",
  "Pa\u0142gan",
  "Kozar",
  "Gumienny",
  "Fedak",
  "Erdmann",
  "Matura",
  "Kapera",
  "Golan",
  "Szczesiak",
  "Szambelan",
  "P\u00f3\u0142ch\u0142opek",
  "\u0141uszczyk",
  "Szymocha",
  "Pielka",
  "Macio\u0142",
  "Brudny",
  "Babij",
  "Zacharczuk",
  "Pilarek",
  "Owsianka",
  "Harasimiuk",
  "Durlak",
  "D\u0142ugajczyk",
  "Wijata",
  "Szyndler",
  "Morka",
  "Mendyka",
  "Kubiaczyk",
  "Kij",
  "Gaudyn",
  "Bok",
  "Pos\u0142uszny",
  "Plich",
  "Pacyga",
  "Mi\u0119tus",
  "Ficner",
  "\u015awierkosz",
  "Krzywo\u0144",
  "Kojder",
  "Kiepura",
  "Godzisz",
  "Ciuba",
  "Bukowiec",
  "Wla\u017alak",
  "Teterycz",
  "\u015acibisz",
  "Sobkiewicz",
  "Raczkiewicz",
  "Konrad",
  "Kohut",
  "Gonet",
  "Frydel",
  "Dyka",
  "Siemek",
  "O\u015bko",
  "Gospodarek",
  "Stryjek",
  "Labudda",
  "Kosiec",
  "Indyk",
  "Franik",
  "Fio\u0142ka",
  "Strycharz",
  "Ostapczuk",
  "Laszczyk",
  "Lament",
  "Korzekwa",
  "K\u0119dziorek",
  "Dziuban",
  "Biega\u0142a",
  "Wito\u0144",
  "Szpara",
  "Pad\u0142o",
  "Otremba",
  "Mierzwiak",
  "Kordus",
  "Bojczuk",
  "Szmelter",
  "Rudzik",
  "Madzia",
  "Grabara",
  "G\u00f3rkiewicz",
  "Bartel",
  "\u015aliz",
  "Sura",
  "Skrzecz",
  "Puto",
  "Pu\u0142ka",
  "Piotrowiak",
  "Mazan",
  "Kobry\u0144",
  "Klatka",
  "Januchta",
  "Grubba",
  "Zaucha",
  "Sularz",
  "Siergiej",
  "Pianka",
  "J\u0119druszczak",
  "Groth",
  "Sobisz",
  "Siejak",
  "Re\u0107ko",
  "Lorens",
  "Ceg\u0142a",
  "Wochnik",
  "Kury\u015b",
  "Gregorowicz",
  "Filek",
  "Salawa",
  "Piekarek",
  "Pabisiak",
  "Glonek",
  "Butrym",
  "Przewo\u017aniak",
  "Macek",
  "Konstanty",
  "Kolber",
  "J\u0119drasiak",
  "W\u0119\u017cyk",
  "Szaj",
  "Malara",
  "K\u0142oczko",
  "Karsznia",
  "Golenia",
  "Zajko",
  "Wudarczyk",
  "Stanuch",
  "Niklewicz",
  "Matejczyk",
  "Kopyto",
  "Grygorowicz",
  "Szajda",
  "Stachelek",
  "S\u0142yk",
  "Loska",
  "Job",
  "Dziadura",
  "Dworniczak",
  "Skubis",
  "Obst",
  "Kazimierczyk",
  "Cymer",
  "Ciak",
  "Chudoba",
  "Achtelik",
  "Tytko",
  "Skupin",
  "Skierka",
  "Panu\u015b",
  "Pabi\u015b",
  "Folta",
  "Bogaczyk",
  "Basa",
  "Trzpil",
  "Morek",
  "Kloska",
  "Kapustka",
  "Gzyl",
  "Go\u0142o\u015b",
  "Danel",
  "Borkiewicz",
  "Araszkiewicz",
  "Miotke",
  "Rezler",
  "Potyra\u0142a",
  "Pacholak",
  "Herba",
  "Grzenia",
  "Giezek",
  "Gajowiak",
  "Filak",
  "Fechner",
  "Dro\u017adzik",
  "Cyman",
  "Wieczerzak",
  "Str\u00f3\u017c",
  "Staciwa",
  "Rucha\u0142a",
  "Rogal",
  "Reszke",
  "Kurpisz",
  "Gryga",
  "Stempniak",
  "Matraszek",
  "K\u00f3zka",
  "Elsner",
  "Boba",
  "Bar\u0142\u00f3g",
  "Kiliszek",
  "Jessa",
  "Ignatiuk",
  "Gogola",
  "Drobek",
  "Lica",
  "Larysz",
  "Kalka",
  "Dziczek",
  "Czupryn",
  "\u017bo\u0142na",
  "Pytko",
  "Misiarz",
  "Majnusz",
  "Kaszkowiak",
  "Jonak",
  "Basista",
  "Pot\u0119ga",
  "Natanek",
  "Matyszczak",
  "Majerczyk",
  "\u0141apaj",
  "Korzonek",
  "Ja\u015bko",
  "Futyma",
  "Duszczyk",
  "Anto\u0144czak",
  "Wysota",
  "Dela",
  "Stawowczyk",
  "Milczarczyk",
  "Malisz",
  "Andrearczyk",
  "\u017bynda",
  "Swaczyna",
  "Ryndak",
  "Moskalik",
  "Mitoraj",
  "\u0141y\u015b",
  "\u0141epek",
  "Knie\u0107",
  "Janisz",
  "Gorol",
  "Ci\u0119\u017cka",
  "\u017byrek",
  "Zmarz\u0142y",
  "Wojtaszczyk",
  "Szygu\u0142a",
  "Szalast",
  "Rz\u0105d",
  "Nicewicz",
  "Danieluk",
  "Bulak",
  "Wojtasiewicz",
  "Pleskot",
  "Materek",
  "Kurczak",
  "Dytko",
  "\u015awistek",
  "Szafarz",
  "Litwa",
  "Kreczmer",
  "Idec",
  "Grabczak",
  "Goliszek",
  "Flieger",
  "Filiks",
  "Dyszy",
  "B\u0142a\u017cejczak",
  "Maksimowicz",
  "Komisarczyk",
  "Jewu\u0142a",
  "Hallmann",
  "Gabara",
  "Budzy\u0144",
  "Andruszko",
  "Pa\u0142yga",
  "Moj",
  "Koterba",
  "Gruza",
  "Gamo\u0144",
  "Pasierbek",
  "Kuchciak",
  "Kanik",
  "Cis",
  "Zegar",
  "Sadlik",
  "Paprotny",
  "Nalazek",
  "Mikita",
  "Kucab",
  "Kranc",
  "Godzik",
  "Sip",
  "Powa\u0142ka",
  "Penkala",
  "Pachuta",
  "Nagel",
  "Litwinowicz",
  "Kukuczka",
  "Knysak",
  "Fojt",
  "Brejnak",
  "Tasarz",
  "Zielke",
  "Zara\u015b",
  "Zaranek",
  "Waleczek",
  "Rubaj",
  "Bazylewicz",
  "Bany\u015b",
  "Balawender",
  "Zmuda",
  "Wojcik",
  "\u0141abno",
  "G\u0119siarz",
  "Frost",
  "Bany",
  "\u017bero",
  "Rudowicz",
  "Nyk",
  "Milcarz",
  "Lipowicz",
  "Kycia",
  "Ko\u015bcio\u0142ek",
  "Korda",
  "Berus",
  "Wiese",
  "Olkowicz",
  "Dzie\u017ca",
  "Doroszkiewicz",
  "Cetera",
  "Pazdan",
  "Pacia",
  "Kempka",
  "Dydak",
  "\u015acibior",
  "Szyjka",
  "Pyziak",
  "Ple\u015bniak",
  "Maszczyk",
  "Ludwiniak",
  "Zadora",
  "Strug",
  "Mokwa",
  "\u0141asak",
  "Kulczak",
  "Kruszona",
  "Zacharewicz",
  "Mi\u0119kina",
  "Klaus",
  "Glego\u0142a",
  "Wyderka",
  "Maleszka",
  "Malcherek",
  "Lew",
  "Kulis",
  "Bodzak",
  "B\u0142aziak",
  "Bart\u0142omiejczyk",
  "To\u015b",
  "Kubasiak",
  "Dorobisz",
  "Cukier",
  "Cie\u0107ko",
  "Zapadka",
  "K\u0142osowicz",
  "Kasak",
  "Czubaszek",
  "Baumgart",
  "Szemraj",
  "Nogie\u0107",
  "Burczak",
  "Pietra\u015b",
  "Ostafin",
  "Noculak",
  "Kukie\u0142a",
  "Fogel",
  "Duczek",
  "Cylwik",
  "Biernacik",
  "Wydrych",
  "Szajek",
  "Siwczak",
  "Majewicz",
  "\u0141osiak",
  "Karkut",
  "Durys",
  "Chwalisz",
  "Bembenek",
  "Bartkowicz",
  "Piskor",
  "Mikus",
  "Ksi\u0119\u017cyk",
  "Goss",
  "Drewniok",
  "B\u0105kiewicz",
  "W\u00f3dka",
  "Wota",
  "Pra\u017cmo",
  "Kiwior",
  "Bogda\u0142",
  "Rubacha",
  "Hanus",
  "Wasiewicz",
  "Trochimiuk",
  "Szwiec",
  "Suszka",
  "Palak",
  "Ziemann",
  "Ma\u0107czak",
  "Kruzel",
  "Ko\u0142aczyk",
  "Kapka",
  "Jodko",
  "Jeszke",
  "Gros",
  "Gendek",
  "Dubik",
  "Wa\u017cna",
  "Piercha\u0142a",
  "Nieszporek",
  "Kandora",
  "Janasz",
  "Gryszkiewicz",
  "Drobik",
  "Cio\u0142czyk",
  "Wo\u0142kowicz",
  "Tylman",
  "Pitu\u0142a",
  "Pioch",
  "Pilich",
  "Marach",
  "Malon",
  "Lepa",
  "Kaliciak",
  "Joszko",
  "Hejna",
  "Gryta",
  "Frelich",
  "Be\u0142z",
  "Bakalarczyk",
  "N\u00f3\u017cka",
  "Holewa",
  "Fierek",
  "\u017buchowicz",
  "Wojtunik",
  "Trzop",
  "Mas\u0142o\u0144",
  "Linda",
  "Kurp",
  "Gryka",
  "Draus",
  "Rezmer",
  "Mizak",
  "Makurat",
  "Ko\u015bcik",
  "Helman",
  "Gendera",
  "Dydo",
  "Bondaruk",
  "Bodek",
  "Wujec",
  "Sady",
  "Przekwas",
  "Postawa",
  "Polasik",
  "Plebanek",
  "Lejk",
  "Kacperek",
  "Go\u0142ofit",
  "Tomys",
  "\u015awiadek",
  "Mizga\u0142a",
  "Kubrak",
  "Ernst",
  "Wielgos",
  "Martynowicz",
  "Drela",
  "Ziarnik",
  "Stasica",
  "Semik",
  "Mytych",
  "Melka",
  "Marat",
  "D\u0105br\u00f3wka",
  "Wyroba",
  "Siudek",
  "Senator",
  "Ryszkiewicz",
  "Podsiedlik",
  "Ma\u0142ys",
  "Lepianka",
  "Giersz",
  "Zugaj",
  "Procek",
  "Makosz",
  "Kunda",
  "Zi\u00f3\u0142ko",
  "Trzyna",
  "Stroka",
  "Rzeszut",
  "Pyza",
  "Kr\u0119\u017co\u0142ek",
  "Kazior",
  "Fidos",
  "So\u0142ek",
  "Gordon",
  "Dubis",
  "Ciocho\u0144",
  "Bieszke",
  "\u017bo\u0142nierczyk",
  "Sobstyl",
  "Skalik",
  "Namys\u0142o",
  "Litewka",
  "Krzysztofek",
  "Grycz",
  "Felu\u015b",
  "Downar",
  "Szram",
  "Oleksik",
  "Milej",
  "Kudela",
  "Klaja",
  "Giedroj\u0107",
  "Getka",
  "Durma",
  "Dudko",
  "D\u0119bosz",
  "Browarczyk",
  "S\u0105siadek",
  "Picheta",
  "Peciak",
  "Nie\u0107ko",
  "Midura",
  "Maciejko",
  "Gregorek",
  "W\u0105siewicz",
  "Twardy",
  "Szachniewicz",
  "Sypek",
  "Sojda",
  "Saran",
  "Mosio\u0142ek",
  "Gu\u015bciora",
  "Golak",
  "Ellwart",
  "Drewicz",
  "Barszczak",
  "W\u00f3jt",
  "Strawa",
  "Sereda",
  "Rejmer",
  "Prostak",
  "Ko\u0142ak",
  "Klekot",
  "Gerlach",
  "Ciep\u0142a",
  "Barankiewicz",
  "Welc",
  "Skotarek",
  "Sad\u0142ocha",
  "Roszkiewicz",
  "Po\u0142etek",
  "Ofiara",
  "Kie\u0142bus",
  "Ka\u0142wak",
  "Jas",
  "Jarkiewicz",
  "Jambor",
  "Hartman",
  "Gra\u015b",
  "Ra\u017aniak",
  "Janc",
  "Doroz",
  "Baster",
  "Banak",
  "Sp\u00f3lnik",
  "Poreda",
  "Orwat",
  "Matyjas",
  "Laskus",
  "Bajak",
  "Witko",
  "\u015alimak",
  "Sapeta",
  "Sadownik",
  "Roszko",
  "Nazarewicz",
  "Mrotek",
  "Gnyp",
  "Dziarmaga",
  "Zaniewicz",
  "Walusiak",
  "Toborek",
  "Szulim",
  "Pawliczak",
  "Niko\u0142ajuk",
  "Myszor",
  "Mila",
  "Liedtke",
  "Korpal",
  "Ja\u017awiec",
  "Groborz",
  "\u015awierkot",
  "Saba\u0142a",
  "Kluj",
  "\u017bach",
  "Wawrzy\u0144czyk",
  "Szumi\u0142o",
  "Sulich",
  "St\u0119pak",
  "Rutowicz",
  "Krzyszczak",
  "Kie\u0142bik",
  "Gogol",
  "Buszkiewicz",
  "Basaj",
  "Bartu\u015b",
  "Samulak",
  "Ryfa",
  "Potoczna",
  "Panicz",
  "Le\u015bny",
  "Lada",
  "Kuska",
  "Gleba",
  "Folga",
  "Barczuk",
  "\u015alebioda",
  "Olma",
  "Ku\u015bnierek",
  "Krzan",
  "Hubert",
  "Grzebyk",
  "Fras",
  "Durlej",
  "Pielach",
  "Klin",
  "J\u0119drak",
  "Frelek",
  "Brz\u0105ka\u0142a",
  "Borysiak",
  "Zagozda",
  "\u015ali\u017c",
  "Szkopek",
  "Ra\u017any",
  "Olearczyk",
  "Miro\u0144czuk",
  "Chyb",
  "\u017bybura",
  "\u017belazo",
  "Kunka",
  "Kosa\u0142ka",
  "Gosz",
  "Dulas",
  "\u017belazek",
  "Terka",
  "So\u015bniak",
  "Pikor",
  "Pezda",
  "Hadam",
  "Gro\u0144",
  "Fal",
  "Chalimoniuk",
  "Karnas",
  "Uzi\u0119b\u0142o",
  "Grochola",
  "Gawliczek",
  "Freitag",
  "\u0106miel",
  "Wac\u0142aw",
  "Symonowicz",
  "Strzoda",
  "Sterna",
  "Spad\u0142o",
  "Rajtar",
  "Krzyka\u0142a",
  "Holc",
  "Gronostaj",
  "Barej",
  "Wasilewicz",
  "Podg\u00f3rny",
  "\u0141apot",
  "Lepak",
  "Hojda",
  "Dziuda",
  "Klup\u015b",
  "Brze\u017aniak",
  "Bojarczuk",
  "Tryka",
  "Nalewajek",
  "Kud\u0142acik",
  "Kubasiewicz",
  "Bazyluk",
  "Bartoszak",
  "Zbylut",
  "To\u0142oczko",
  "Szaruga",
  "Obuchowicz",
  "Gryska",
  "Bociek",
  "Wowra",
  "Szramka",
  "Spychaj",
  "Roj",
  "Musiolik",
  "Franas",
  "D\u0142ubak",
  "Cholewka",
  "Bobko",
  "Bia\u0142ous",
  "Osial",
  "Nieborak",
  "Minta",
  "Kozica",
  "Kowara",
  "Gwara",
  "Tekieli",
  "Pancerz",
  "Mleczak",
  "Celuch",
  "Zapi\u00f3r",
  "Grabo\u015b",
  "Fidura",
  "Cyrek",
  "Bracha",
  "Gradek",
  "Noras",
  "Mulawa",
  "Moniuszko",
  "Kapcia",
  "Gumienna",
  "Graj",
  "Gilewicz",
  "\u017b\u00f3\u0142tek",
  "Wojtalewicz",
  "Szumny",
  "Opyrcha\u0142",
  "Macha",
  "\u0141uczyk",
  "Hus",
  "Czak",
  "Borzym",
  "Wojtczuk",
  "Winnik",
  "Kuk",
  "Kubanek",
  "Dzie\u0142ak",
  "Dudziec",
  "Cimoch",
  "Ciapa",
  "Buchalik",
  "Zbr\u00f3g",
  "W\u0119grzyniak",
  "Wawrzkiewicz",
  "Teodorowicz",
  "Szko\u0142a",
  "Sutor",
  "Kapu\u015bcik",
  "Hajdas",
  "Fo\u0142ta",
  "Burkiewicz",
  "Aleksa",
  "Wajer",
  "Siembab",
  "Kozon",
  "Wojew\u00f3dka",
  "Wenda",
  "Majos",
  "Huczek",
  "Domo\u0144",
  "Zubel",
  "Szymaniuk",
  "Salomon",
  "Mikiciuk",
  "Grodek",
  "Wiel\u0105dek",
  "Szyma\u0144czak",
  "Sommer",
  "Saczuk",
  "Pastuszek",
  "Mroczko",
  "\u0141okaj",
  "Deptuch",
  "Wawak",
  "Szczepaniec",
  "Romejko",
  "Rogacz",
  "Poczta",
  "Nowotka",
  "Jaszcz",
  "Jany",
  "Hewelt",
  "Stach\u00f3w",
  "Smykla",
  "S\u0119dek",
  "Niemira",
  "M\u0142odzik",
  "\u0141yczek",
  "Kleban",
  "Fura",
  "Fudalej",
  "Cyro\u0144",
  "Zago\u017cd\u017con",
  "Kenig",
  "G\u00f3rnisiewicz",
  "Wo\u0142oszyk",
  "Szatanik",
  "Sajda",
  "Pyrkosz",
  "Misiejuk",
  "Miko\u0142ajewicz",
  "Ko\u0142sut",
  "Glenc",
  "Eckert",
  "Dziadowicz",
  "Waszczyk",
  "Szyba",
  "Steckiewicz",
  "Kloch",
  "Kabala",
  "Zamora",
  "Tabi\u015b",
  "Sobk\u00f3w",
  "Pupek",
  "Neugebauer",
  "Ko\u0142tuniak",
  "Galek",
  "St\u00f3j",
  "Rajda",
  "Pruchnik",
  "Kuza",
  "Kara\u015bkiewicz",
  "Judek",
  "J\u0119dryczka",
  "Grzegorzak",
  "Drobniak",
  "Chowaniak",
  "W\u0105sek",
  "Smagacz",
  "P\u0119dzik",
  "Klinger",
  "Kl\u0119czar",
  "Wochna",
  "Rejek",
  "Krakowczyk",
  "Kobak",
  "Kawiak",
  "Grosz",
  "Czubaj",
  "Chor\u0105\u017cewicz",
  "Zadka",
  "Wietecha",
  "Sass",
  "M\u0119cik",
  "Gustaw",
  "Furga",
  "Fr\u0105cz",
  "Dawiec",
  "Wypch\u0142o",
  "Tarasek",
  "Szmaj",
  "Ornat",
  "Huszcza",
  "Dudczak",
  "U\u0142anowicz",
  "Rubin",
  "Pich",
  "Mako\u015b",
  "Kr\u0119pa",
  "Korek",
  "Jonik",
  "Andrejczuk",
  "Wiertel",
  "Soroko",
  "Sk\u0142adanek",
  "Mortka",
  "Ma\u0142ocha",
  "Majsterek",
  "Lemanowicz",
  "Lelito",
  "Krystkowiak",
  "Krasa",
  "Kierat",
  "J\u0119draszczyk",
  "Handke",
  "Dymarczyk",
  "Doruch",
  "Beker",
  "Peszko",
  "Osik",
  "\u0141yp",
  "Karmelita",
  "Herdzik",
  "Brz\u0119k",
  "Bia\u0142czyk",
  "Uss",
  "Pitura",
  "\u0141usiak",
  "Knapek",
  "Gumu\u0142a",
  "Dar\u0142ak",
  "Znojek",
  "Wilkos",
  "Rut",
  "Przekop",
  "Kr\u0119cichwost",
  "Korab",
  "J\u00f3zwik",
  "Jagie\u0142ka",
  "Chylak",
  "Zbiciak",
  "Was\u0105\u017cnik",
  "T\u0142uczek",
  "Syldatk",
  "Parkitny",
  "Juroszek",
  "Wisz",
  "Wiciak",
  "Palonek",
  "Kusik",
  "Kocurek",
  "Kacperczyk",
  "Bluszcz",
  "Wydmuch",
  "Wereda",
  "Tryba\u0142a",
  "Sito",
  "Pietraszkiewicz",
  "Nojek",
  "Madziar",
  "Kazana",
  "Szulczyk",
  "Roso\u0142ek",
  "Roskosz",
  "Pro\u0107",
  "Mazek",
  "Koniecko",
  "Horbacz",
  "Zastawny",
  "Orszulik",
  "Mesjasz",
  "Margas",
  "Ko\u017alak",
  "Dzidek",
  "Damek",
  "Zinkiewicz",
  "Sznura",
  "Sapa\u0142a",
  "Piaseczna",
  "Osada",
  "Koziarz",
  "Korta",
  "K\u0142osiewicz",
  "Klyszcz",
  "Janoszek",
  "Deszcz",
  "Ok\u0142a",
  "Matacz",
  "Hankiewicz",
  "Front",
  "Dara\u017c",
  "Czura",
  "Bylina",
  "Bugiel",
  "Anio\u0142a",
  "Amanowicz",
  "Zach",
  "Staro\u015bciak",
  "Kliszcz",
  "Hada\u0142a",
  "Czopik",
  "Bytner",
  "Wo\u015bko",
  "Wawrzyn",
  "\u015awit",
  "Sanetra",
  "Pyszczek",
  "Potaczek",
  "Osman",
  "Materka",
  "Madura",
  "Knia\u017a",
  "Gryciuk",
  "Fidor",
  "Dunal",
  "Dobro\u0144",
  "Chlebda",
  "S\u0142upik",
  "Osica",
  "Oleksak",
  "Maraszek",
  "Kr\u0119giel",
  "Kopytko",
  "Gomo\u0142a",
  "Dro\u017adziel",
  "Szott",
  "Szkup",
  "Posmyk",
  "M\u0142otek",
  "Klejna",
  "Ja\u0142owiec",
  "Heinrich",
  "Haraburda",
  "Grupa",
  "Dziadkiewicz",
  "Zaczyk",
  "Rapa",
  "\u0141odej",
  "Lempart",
  "Lamch",
  "G\u0142uszko",
  "Cudzich",
  "Brojek",
  "Ziemak",
  "Tusk",
  "Kieloch",
  "Dziduch",
  "Dudkowiak",
  "Czerner",
  "Sommerfeld",
  "Migo\u0144",
  "Macheta",
  "Dusik",
  "\u0106wirko",
  "Bilik",
  "Sydor",
  "Swi\u0105tek",
  "Sporek",
  "Olesiejuk",
  "Kutek",
  "Jaszczur",
  "Jarmu\u017c",
  "Gronkiewicz",
  "Witan",
  "Staniczek",
  "Rz\u0105ca",
  "Roter",
  "Pracz",
  "Hnat",
  "Cydzik",
  "Szatko",
  "Styrna",
  "Podle\u015bna",
  "Oleksa",
  "Nie\u015bcior",
  "Matyjaszek",
  "\u0141asica",
  "Kwapie\u0144",
  "Koronkiewicz",
  "Ho\u0142ota",
  "Elert",
  "Czochara",
  "Toczko",
  "\u015awi\u0119s",
  "S\u0142ysz",
  "Salach",
  "Le\u015bna",
  "G\u0142ownia",
  "Galica",
  "Cieniuch",
  "Szulist",
  "Pedrycz",
  "Kr\u00f3lczyk",
  "Zyzik",
  "Zaborek",
  "Ska\u0142ka",
  "Sankiewicz",
  "Pleban",
  "Martin",
  "Lewek",
  "J\u0119drys",
  "Guzdek",
  "Duma\u0142a",
  "Wszo\u0142a",
  "R\u0119bi\u015b",
  "Po\u015bnik",
  "Porzucek",
  "Hawro",
  "Dzi\u00f3b",
  "Zwara",
  "Wiraszka",
  "Romankiewicz",
  "Roch",
  "Pale\u0144",
  "Ogonek",
  "Makar",
  "Majdan",
  "Kozdr\u00f3j",
  "Kozdro\u0144",
  "Jachna",
  "Duniec",
  "Du\u0142ak",
  "Wojtanowicz",
  "Waloch",
  "Ubysz",
  "Sto\u017cek",
  "Ma\u0142ycha",
  "Kmak",
  "Hass",
  "Frydrychowicz",
  "Domka",
  "\u017bugaj",
  "Zubowicz",
  "Wyrwa\u0142",
  "Mordal",
  "Kordys",
  "Gozdur",
  "Gabrych",
  "Zbro\u017cek",
  "Zbroszczyk",
  "Wojto\u0144",
  "T\u00f3rz",
  "Torbus",
  "Letkiewicz",
  "Lampart",
  "Superson",
  "Sopata",
  "Sobi\u0142o",
  "Sapa",
  "Salwin",
  "Pera",
  "Organi\u015bciak",
  "Matwiejczyk",
  "Matejuk",
  "Ma\u0142y",
  "Kr\u00fcger",
  "Dyszkiewicz",
  "Basak",
  "Ankiewicz",
  "Adamiuk",
  "Syka\u0142a",
  "Skonieczka",
  "Pawe\u0142ko",
  "Nojman",
  "Iskierka",
  "Zi\u0119cik",
  "Trojanek",
  "Sadlak",
  "Nieradko",
  "Behrendt",
  "Wojewodzic",
  "Polewka",
  "Zas\u0119pa",
  "Szczerek",
  "Sza\u0142ata",
  "Sot",
  "Mleczek",
  "Kukawka",
  "Kaczmarkiewicz",
  "Dorobek",
  "Burchard",
  "Blaut",
  "Witka",
  "Sasak",
  "Pasiak",
  "Panasiewicz",
  "Motak",
  "Lizurej",
  "Kubo\u0144",
  "J\u0119draszek",
  "Dylik",
  "Cal",
  "Buszko",
  "Burnat",
  "Wyskiel",
  "Winek",
  "Wiertelak",
  "Wiak",
  "Ro\u015b",
  "Orzeszek",
  "Ochota",
  "Mijas",
  "Maculewicz",
  "Kaja",
  "Ciesielka",
  "Bejm",
  "Szmuc",
  "Sygut",
  "Siarkiewicz",
  "Ryznar",
  "Patoka",
  "Miszkurka",
  "Kude\u0142ka",
  "Krzy\u015bko",
  "Galon",
  "Buczma",
  "Ziegler",
  "Uroda",
  "Turczyk",
  "Tolak",
  "Sypu\u0142a",
  "Sadowy",
  "Rasa\u0142a",
  "Kazubek",
  "Han",
  "Wasiuk",
  "Stempin",
  "Stawczyk",
  "Prokopiak",
  "Pospiech",
  "Polakiewicz",
  "Olas",
  "Maruszczyk",
  "Kapinos",
  "Kabza",
  "Szwa\u0142ek",
  "Smaga\u0142a",
  "Musia\u0142a",
  "Miksza",
  "Lampa",
  "Kulon",
  "Koczara",
  "Drynda",
  "Szczypi\u00f3r",
  "Pawe\u0142kiewicz",
  "Myk",
  "Kuczak",
  "Ko\u0142ata",
  "\u017bywica",
  "Tondera",
  "Szmalec",
  "Szczap",
  "Sypie\u0144",
  "So\u0142tysek",
  "Mosur",
  "Ko\u015bciesza",
  "Kosowicz",
  "Kolendo",
  "Huber",
  "Giel",
  "Ga\u0142\u0119za",
  "Dyja",
  "Cacko",
  "Apanowicz",
  "Wandas",
  "Siebert",
  "Moneta",
  "Ziajka",
  "Sieg",
  "Paluszak",
  "Licho\u0144",
  "Kastelik",
  "Gwizdek",
  "Drewa",
  "Andrys",
  "Zbrze\u017aniak",
  "Wlaz\u0142y",
  "Wittbrodt",
  "Niksa",
  "Habdas",
  "Fry\u015b",
  "Dokt\u00f3r",
  "Detka",
  "Cieplucha",
  "Ciarka",
  "Witkowicz",
  "Wardza\u0142a",
  "St\u0105p\u00f3r",
  "Pniak",
  "Pierzak",
  "Kryk",
  "Ko\u017cuszek",
  "Kohnke",
  "Kapa\u0142ka",
  "Domino",
  "Czuj",
  "Boksa",
  "Wocial",
  "Stuglik",
  "Steciuk",
  "Smela",
  "Plona",
  "Piwowarek",
  "Pernak",
  "Minkina",
  "Klos",
  "Halik",
  "Dzika",
  "Dargacz",
  "Damian",
  "Adrian",
  "W\u0119grzynek",
  "Tomal",
  "\u015awierad",
  "Szkatu\u0142a",
  "Sajn\u00f3g",
  "Kudlak",
  "Golczyk",
  "Fronczyk",
  "Czapiga",
  "B\u0142a\u017cejak",
  "Bejma",
  "Bartela",
  "Tadeusiak",
  "N\u0119dzi",
  "Kurcz",
  "Jasionek",
  "Heleniak",
  "Ziarek",
  "Zera",
  "Sarniak",
  "R\u00f3\u017cak",
  "Ligas",
  "Kuzior",
  "Kuder",
  "Korzeniak",
  "Fac",
  "Domowicz",
  "D\u0119bniak",
  "Cieciora",
  "Chaberek",
  "Bogusiewicz",
  "Block",
  "Wardziak",
  "Prawdzik",
  "Niebudek",
  "Jeszka",
  "Szpyrka",
  "Szkaradek",
  "Starek",
  "Pasich",
  "Lademann",
  "Jantos",
  "Grzelec",
  "Zapora",
  "Wnuczek",
  "W\u0105sala",
  "Pompa",
  "Ma\u0142as",
  "Janka",
  "Ga\u0142aj",
  "Dyba\u0142",
  "Chromy",
  "Szpyt",
  "Senger",
  "Prygiel",
  "Pawela",
  "\u0141akota",
  "Jama",
  "Graban",
  "Fogt",
  "Cebulak",
  "Boryczko",
  "Bojdo",
  "Biesek",
  "Arendarczyk",
  "Schubert",
  "Namys\u0142",
  "Milewczyk",
  "Hetma\u0144czyk",
  "Dyczko",
  "Dankiewicz",
  "Czerniec",
  "Sta\u015bko",
  "Rochowiak",
  "Misiuk",
  "Markiel",
  "Ksel",
  "Krzy\u017costaniak",
  "Elwart",
  "Delekta",
  "Z\u0119bik",
  "Siatka",
  "Niewiara",
  "Miozga",
  "M\u0119tel",
  "Korgul",
  "Karwan",
  "Frank\u00f3w",
  "Domek",
  "Ciepluch",
  "Chojna",
  "Surmiak",
  "Strama",
  "Stein",
  "Siewiera",
  "Robaszkiewicz",
  "Piksa",
  "Kociemba",
  "Klyta",
  "Gromala",
  "Gill",
  "Broszkiewicz",
  "Zontek",
  "Stiller",
  "Rosada",
  "Mieloch",
  "Kornak",
  "Goworek",
  "Gadza\u0142a",
  "Fitas",
  "Uzar",
  "Siedlarz",
  "Rorat",
  "Oskroba",
  "Mitera",
  "Grygorcewicz",
  "Gmurczyk",
  "Dylak",
  "Zybura",
  "Wojtaszak",
  "Wis\u0142a",
  "Wasyluk",
  "Sza\u0142kiewicz",
  "Krzysztoszek",
  "Ko\u015bciuszko",
  "Kasiak",
  "Wyrwich",
  "Wo\u0142oszczuk",
  "\u015aledzik",
  "Smor\u0105g",
  "Satora",
  "Pochro\u0144",
  "Melaniuk",
  "Jajko",
  "Czajor",
  "Bajko",
  "Wojs\u0142aw",
  "Szumiec",
  "Nehring",
  "Naumiuk",
  "Luberda",
  "K\u0119sek",
  "Ja\u015bkowiec",
  "Foit",
  "Fita",
  "Fedyk",
  "Dzia\u0142a",
  "Cygal",
  "Zdancewicz",
  "Walocha",
  "Toma",
  "Soczewka",
  "Monkiewicz",
  "Majtyka",
  "Hynek",
  "Dynia",
  "Czury\u0142o",
  "Bernatek",
  "Apostel",
  "Zawiasa",
  "Piersa",
  "Megger",
  "Kukier",
  "Jarka",
  "Glazik",
  "Dyjas",
  "Bu\u015b",
  "Bona",
  "Bandyk",
  "Zi\u0119ciak",
  "Krajniak",
  "Koperek",
  "Kazberuk",
  "Dziewior",
  "Chachaj",
  "So\u0142oducha",
  "S\u0142omiany",
  "Skolik",
  "P\u0119ksa",
  "Mularz",
  "Kosman",
  "Kolonko",
  "Januszewicz",
  "Gramza",
  "Foremniak",
  "Fija\u0142ek",
  "Cierpka",
  "Polnik",
  "Drwi\u0119ga",
  "Semenowicz",
  "Pieszak",
  "Naro\u017cna",
  "\u0141adniak",
  "Kontny",
  "Klemens",
  "Jancewicz",
  "F\u0105ferek",
  "Bisaga",
  "Z\u0142otnik",
  "Wosiek",
  "Supernak",
  "Kala",
  "Gi\u017ca",
  "Bielat",
  "\u017byto",
  "Rompa",
  "Kurpanik",
  "Ko\u0142pak",
  "Go\u0142as",
  "D\u0142ugozima",
  "Bacia",
  "Wincenciak",
  "Styn",
  "Moczko",
  "Langier",
  "Szrama",
  "Szok",
  "Suchenek",
  "Pieczarka",
  "Parus",
  "Machul",
  "Latko",
  "Krzy\u015bk\u00f3w",
  "Galos",
  "Ekert",
  "Dawidek",
  "Czerkies",
  "Bujas",
  "Andryszczyk",
  "Zuziak",
  "W\u0119grzyk",
  "St\u0105por",
  "Pinda",
  "Muzyk",
  "Malig\u0142\u00f3wka",
  "\u0141ukasiuk",
  "Kinal",
  "Dobosiewicz",
  "Waraksa",
  "Szywa\u0142a",
  "Nasta\u0142y",
  "Mordak",
  "Ligenza",
  "Leszczak",
  "Krauz",
  "Kopa\u0142a",
  "Byzdra",
  "Bartman",
  "Wojtach",
  "Wa\u0142aszek",
  "Szara",
  "Hapka",
  "Wielgat",
  "W\u0119gier",
  "Pokusa",
  "Ma\u0142\u017c",
  "Kononowicz",
  "Hawrylak",
  "Grund",
  "Druszcz",
  "Dacko",
  "Sprycha",
  "Pryszcz",
  "\u0141achut",
  "Dobrosz",
  "Brygo\u0142a",
  "Rygu\u0142a",
  "Pos\u0142uszna",
  "Mydlak",
  "Bernard",
  "Woroch",
  "Uliczka",
  "Tomaszuk",
  "Pastu\u0142a",
  "Pachnik",
  "Kudra",
  "Kretek",
  "Keler",
  "Heczko",
  "Beck",
  "Tekiela",
  "Plizga",
  "Piekacz",
  "Ochab",
  "Maziarczyk",
  "Krzosek",
  "Gabryelczyk",
  "St\u0119pka",
  "Rajch",
  "Owsiany",
  "Kossak",
  "Kocaj",
  "Gierach",
  "Buza",
  "Berendt",
  "Tabak",
  "Przew\u0142oka",
  "Nytko",
  "Kuban",
  "Gebauer",
  "Gajcy",
  "Franaszek",
  "Chwedczuk",
  "Bochnak",
  "Stachewicz",
  "Sosn\u00f3wka",
  "S\u0142owiak",
  "M\u0105dro",
  "Malcharek",
  "\u0141ukasz",
  "Kornek",
  "Hanusiak",
  "Furmankiewicz",
  "Dzikiewicz",
  "Du\u017cy",
  "Delikat",
  "Chojak",
  "Zyga",
  "Pyrz",
  "Pietrusiewicz",
  "Olszyna",
  "Olszowa",
  "Ograbek",
  "Molga",
  "Maron",
  "Jasica",
  "Frymus",
  "Buszta",
  "Woszczak",
  "Woronko",
  "Trawka",
  "Rychcik",
  "Przystupa",
  "Oczko",
  "Migda",
  "Klebba",
  "Jaje",
  "Grabas",
  "Bugno",
  "Bortkiewicz",
  "Weso\u0142a",
  "Sudak",
  "Puc",
  "Przeklasa",
  "Koco\u0142",
  "Goik",
  "B\u0142a\u017cejewicz",
  "Tuzimek",
  "Petrus",
  "Pawlaczek",
  "Pacholczak",
  "Maciejewicz",
  "Jak\u00f3bik",
  "Frania",
  "Duszczak",
  "Domurad",
  "Bednarowicz",
  "Thomas",
  "Rakus",
  "Przyby\u015b",
  "Pasiut",
  "Ma\u0142yszka",
  "Kurz",
  "Kuczaj",
  "Doktor",
  "Tadla",
  "Praczyk",
  "Milka",
  "Leszcz",
  "Kryza",
  "Kryszczuk",
  "Juraszczyk",
  "Durczok",
  "Boduch",
  "Szeja",
  "Pryk",
  "Pitala",
  "Molek",
  "Duchnik",
  "Brachaczek",
  "Wieja",
  "Waloszek",
  "Nawrotek",
  "Naw\u00f3j",
  "Mironiuk",
  "Matyjasek",
  "\u0141achacz",
  "Kub\u00f3w",
  "Kidawa",
  "Jaremek",
  "Hasiak",
  "Gierat",
  "Gaw\u0142owicz",
  "Wichary",
  "Sornat",
  "Solich",
  "Kurczab",
  "Jasnoch",
  "Famu\u0142a",
  "Budrewicz",
  "Pawliszyn",
  "Ku\u0142ach",
  "Kuffel",
  "Konieczek",
  "Ko\u0107win",
  "Imio\u0142czyk",
  "Dyda",
  "Zander",
  "Stochel",
  "Osojca",
  "Mysior",
  "Kuciak",
  "K\u0142\u00f3sek",
  "Buchholz",
  "Zegad\u0142o",
  "Wiewi\u00f3rka",
  "Stochaj",
  "Smolka",
  "Piotrak",
  "Misior",
  "Leoniak",
  "Karwala",
  "Jasina",
  "Ci\u0119ciwa",
  "Ciastek",
  "Chadaj",
  "Bia\u0142ach",
  "Tabisz",
  "Such",
  "Sromek",
  "Rysz",
  "Puch",
  "Plak",
  "Palej",
  "Och",
  "Niedba\u0142",
  "Mytnik",
  "Morga\u0142a",
  "Lukas",
  "Liso\u0144",
  "Kr\u00f3likiewicz",
  "Kamieniak",
  "Jachimczyk",
  "Grzywnowicz",
  "Frukacz",
  "Feliniak",
  "Dzienisz",
  "Dr\u0105\u017cyk",
  "\u017belasko",
  "Waloszczyk",
  "Str\u00f3jw\u0105s",
  "Smoczyk",
  "Klorek",
  "Kajdan",
  "Kajak",
  "Gral",
  "Zawodnik",
  "Ulfik",
  "Sobieszczyk",
  "Skrobot",
  "Ocha\u0142",
  "Le\u017co\u0144",
  "Krywult",
  "Iciek",
  "Gasek",
  "Czenczek",
  "Budze\u0144",
  "Botor",
  "Wik\u0142o",
  "Tymczyszyn",
  "Szpyra",
  "S\u0142onka",
  "Prasek",
  "Majczyna",
  "Lula",
  "Jakubiuk",
  "Hanzel",
  "G\u0142owiak",
  "Calik",
  "Zagrajek",
  "Stefankiewicz",
  "Serzysko",
  "Piechna",
  "Myga",
  "Ma\u015blankiewicz",
  "Kuziora",
  "Korniak",
  "Indyka",
  "Ga\u0142ach",
  "Gadzina",
  "Cyba",
  "Bystrek",
  "Bazela",
  "Wabik",
  "Ragus",
  "Pitek",
  "Mizia",
  "\u0141askawiec",
  "Holeksa",
  "Hajdasz",
  "Fugiel",
  "Bia\u0142asik",
  "Wo\u017aniczko",
  "Wilma",
  "Rode",
  "Pre\u015b",
  "Komander",
  "Klus",
  "Sarosiek",
  "Sadoch",
  "Osipowicz",
  "Lelonek",
  "Korbut",
  "Jarmu\u017cek",
  "W\u0142odyka",
  "J\u00f3zefczak",
  "J\u0119dra",
  "Hamerla",
  "G\u0119gotek",
  "Domi\u0144czak",
  "Wypi\u00f3r",
  "Sudnik",
  "S\u0142oboda",
  "Pela",
  "Kup\u015b",
  "Kostorz",
  "Kosak",
  "Kopy\u015b\u0107",
  "Jarmu\u0142a",
  "Daniec",
  "Blank",
  "Balcewicz",
  "Starostka",
  "Siemie\u0144czuk",
  "Reiter",
  "Mycek",
  "Mi\u0119tka",
  "\u0141upina",
  "Lipok",
  "Knych",
  "Drobisz",
  "Cuch",
  "Wojtarowicz",
  "Wojniak",
  "Piechura",
  "Meissner",
  "Lemiesz",
  "Kl\u0119k",
  "Jargie\u0142o",
  "Jamroz",
  "Huczko",
  "Ceynowa",
  "Trochim",
  "Kremer",
  "Janic",
  "Gal",
  "Cyrulik",
  "Bejger",
  "Bawo\u0142",
  "Szczepan",
  "Plewnia",
  "P\u0119drak",
  "Niedo\u015bpia\u0142",
  "Maras",
  "Klepka",
  "Kawulok",
  "Katana",
  "Bronka",
  "Bender",
  "Ba\u0142dys",
  "Wawrzonek",
  "Taranek",
  "Tadych",
  "Szyma\u0142a",
  "Stebel",
  "Skup",
  "Skuba\u0142a",
  "Pasieczna",
  "Karkocha",
  "Hak",
  "G\u0105szczak",
  "Py\u015b",
  "Pra\u017cuch",
  "Politowicz",
  "Piestrzeniewicz",
  "Pajek",
  "Nitek",
  "Kozok",
  "Kowala",
  "Kalinka",
  "Galuba",
  "Buk",
  "Bre\u015b",
  "Bodych",
  "Bittner",
  "Bakiera",
  "Rembacz",
  "Podg\u00f3rna",
  "Myrcik",
  "Mojsa",
  "Karpiak",
  "Kajdas",
  "Gregorczuk",
  "Dziurla",
  "Dzienniak",
  "Dyrek",
  "\u017bo\u0142\u0105dkiewicz",
  "Szumacher",
  "Sado",
  "Pyszny",
  "Naro\u017cny",
  "Kuszyk",
  "Jakimiak",
  "Dynak",
  "Dejneka",
  "Wiekiera",
  "Tatarczuk",
  "Rudyk",
  "Nie\u015bcioruk",
  "Laszkiewicz",
  "Go\u0142ota",
  "Golisz",
  "B\u0105bel",
  "Tacza\u0142a",
  "\u015awi\u0107",
  "Siciarz",
  "Ropiak",
  "Pacura",
  "Makulec",
  "Krauza",
  "Grzesiek",
  "Gemza",
  "Dering",
  "Banek",
  "Andziak",
  "Wiza",
  "Trojanowicz",
  "Parkitna",
  "Pacholik",
  "Majtczak",
  "Krenc",
  "Koniec",
  "Wawrze\u0144czyk",
  "Stupak",
  "Roda",
  "Maciejczuk",
  "Irla",
  "Husak",
  "Fu\u0142awka",
  "Fabia\u0144czyk",
  "Bryda",
  "Zackiewicz",
  "Szoka",
  "Melcer",
  "Kempny",
  "Dulemba",
  "Duc",
  "Ziniewicz",
  "Truchel",
  "Szajner",
  "Petryk",
  "Peda",
  "Obarzanek",
  "Maszkiewicz",
  "\u0141abaj",
  "Cymba\u0142a",
  "Biesaga",
  "Zdobylak",
  "Wojtiuk",
  "Ulrych",
  "Szymk\u00f3w",
  "Sporysz",
  "Smardz",
  "Mandrysz",
  "Kulus",
  "Duras",
  "Dumin",
  "Borejko",
  "Wy\u0142upek",
  "Ufniarz",
  "Stypka",
  "M\u0142y\u0144czyk",
  "Miros",
  "Maciuk",
  "Hrabia",
  "Burzec",
  "Buksa",
  "Wygoda",
  "Tomzik",
  "Pindral",
  "Nijak",
  "Mszyca",
  "Maciejuk",
  "Kud\u0142acz",
  "Dziwak",
  "Chaba",
  "Borkowicz",
  "Berek",
  "\u017bakiewicz",
  "Wykr\u0119t",
  "Sztuba",
  "Smyka\u0142a",
  "Pyc",
  "P\u0119ciak",
  "Parzonka",
  "Kyc",
  "Klemczak",
  "G\u0105sienica",
  "Gabryszak",
  "Cz\u0119\u015bcik",
  "Ciso\u0144",
  "Zmy\u015blony",
  "Komisarek",
  "Fico\u0144",
  "Citko",
  "Bidas",
  "Bas",
  "\u017babierek",
  "Wyciszkiewicz",
  "Tarach",
  "Staniewicz",
  "Reichel",
  "Panasewicz",
  "Kucewicz",
  "Kilar",
  "Hein",
  "Fronia",
  "Derek",
  "Bru\u015b",
  "Anto\u0144",
  "Pawlos",
  "Ochwat",
  "Kurbiel",
  "Gosik",
  "Gierasimiuk",
  "Doroba",
  "Ch\u0142\u0105d",
  "Wrochna",
  "Protasiuk",
  "Opalach",
  "Mu\u0107ko",
  "Martyn",
  "Drgas",
  "Ceran",
  "Bryczek",
  "Ziarno",
  "Wo\u0142od\u017ako",
  "Wac",
  "Szpala",
  "Szlachcic",
  "Rurka",
  "Oczkowicz",
  "Mik",
  "Ma\u0142ysiak",
  "Kubek",
  "Imiela",
  "Grabo\u0144",
  "Garbacik",
  "Dolega",
  "Broncel",
  "Baum",
  "Bancerz",
  "Siedlik",
  "Mi\u0105sko",
  "Lenc",
  "Konat",
  "Kaletka",
  "Jenek",
  "Honkisz",
  "Dro\u015b",
  "Suchojad",
  "Ratka",
  "Raba",
  "Lulek",
  "Komperda",
  "Ko\u0142odziejak",
  "Koloch",
  "Kolka",
  "Joniak",
  "Jezior",
  "Faltyn",
  "Dyjach",
  "Czulak",
  "Cop",
  "Wyro\u015blak",
  "Woda",
  "Stranc",
  "Solis",
  "Skomra",
  "Sierpie\u0144",
  "Rze\u017aniczek",
  "Pajdak",
  "Mostek",
  "Machowiak",
  "Jandu\u0142a",
  "Fitrzyk",
  "Welenc",
  "Tyczka",
  "Skiepko",
  "Potok",
  "Olewniczak",
  "Nitkiewicz",
  "Myrcha",
  "Krata",
  "Kara",
  "Ho\u0142ysz",
  "Ha\u0142ka",
  "Florian",
  "Dziurdzia",
  "Dryka",
  "Sys\u0142o",
  "Rolek",
  "M\u0142ocek",
  "Idzi",
  "Haponiuk",
  "Gr\u0119bowiec",
  "G\u0119ca",
  "Bochnia",
  "\u015alipek",
  "Sieczko",
  "Pierz",
  "Nyc",
  "\u0141acina",
  "Ludwisiak",
  "Kujda",
  "Hutyra",
  "Dziugie\u0142",
  "Bia\u0142ka",
  "Zemanek",
  "Zawartka",
  "Smyl",
  "Smolec",
  "S\u0142oka",
  "Putek",
  "Pietrewicz",
  "Lepka",
  "Krzeszowiec",
  "Kowal\u00f3wka",
  "Jo\u015bko",
  "Hamrol",
  "Gapys",
  "Antoszczyk",
  "Turo\u0144",
  "Teter",
  "Surdel",
  "Pieczyrak",
  "Mudlaff",
  "Manista",
  "Kolek",
  "Kadela",
  "Jeka",
  "Jamro\u017cek",
  "Goliasz",
  "Dywan",
  "Drewnik",
  "D\u0105bro\u015b",
  "Cia\u015b",
  "Obia\u0142a",
  "Nocek",
  "Marko",
  "\u0141adziak",
  "Hada\u015b",
  "Dulik",
  "Dorynek",
  "Wola\u0144czyk",
  "Stoltmann",
  "Rozumek",
  "\u0141udzik",
  "\u0141a\u015b",
  "Leoniuk",
  "Krzyk",
  "Karol",
  "Kamyszek",
  "Filusz",
  "Czermak",
  "Budych",
  "\u017b\u00f3\u0142kiewicz",
  "Tatarczyk",
  "Pietrus",
  "Pachowicz",
  "Niesporek",
  "Kultys",
  "Kornet",
  "Kajstura",
  "Grze\u015bk\u00f3w",
  "Dub",
  "Drobot",
  "Urynowicz",
  "Swacha",
  "Prokopczuk",
  "Michnowicz",
  "Malka",
  "Labocha",
  "Capiga",
  "Zawalich",
  "Wizner",
  "Startek",
  "Smolorz",
  "Rozynek",
  "Pal",
  "Madajczyk",
  "\u0141awniczek",
  "Haremza",
  "Bejnarowicz",
  "\u017buberek",
  "Windak",
  "Sobolak",
  "Sibiga",
  "Rajczak",
  "Pude\u0142ek",
  "Michalkiewicz",
  "Fularczyk",
  "Broniarek",
  "\u017babka",
  "Towarek",
  "Sugier",
  "Pikula",
  "Pawlonka",
  "Marosz",
  "Kut",
  "Grymuza",
  "D\u0105bkiewicz",
  "Ciechowicz",
  "Brodawka",
  "Borzych",
  "Bela",
  "Zagu\u0142a",
  "Tyniec",
  "Trepczyk",
  "Stwora",
  "Paczos",
  "Olbrych",
  "Ogrodowicz",
  "Michel",
  "Mazepa",
  "Lazarek",
  "Krzystek",
  "Ja\u017cd\u017cyk",
  "Goska",
  "Fraszczyk",
  "Dro\u017cd\u017cal",
  "Cofa\u0142a",
  "Cho\u0142ody",
  "Wawrzyk",
  "Prokurat",
  "Policht",
  "P\u0142odzie\u0144",
  "Pasztaleniec",
  "Osipiuk",
  "Mate\u0144ko",
  "Kiciak",
  "Grotek",
  "Cz\u0142onka",
  "\u017bal",
  "Zimmer",
  "Wosiak",
  "Srokosz",
  "Pa\u017adziora",
  "Pato\u0142a",
  "Pa\u0142\u0119ga",
  "Orawiec",
  "Nastaj",
  "Mirgos",
  "Merda",
  "Machniak",
  "\u0141okietek",
  "Fogiel",
  "Elias",
  "\u015awiergiel",
  "Stempel",
  "Skocz",
  "Potoczek",
  "Penar",
  "Miecznik",
  "Kwapis",
  "Jak\u00f3biak",
  "Gietka",
  "Flisek",
  "Dudzicz",
  "Cich",
  "Broniek",
  "Wiercigroch",
  "Usarek",
  "Tryc",
  "Szylar",
  "Szczot",
  "Ptok",
  "Prystupa",
  "Preuss",
  "Piekara",
  "\u0141aszczyk",
  "Kurzaj",
  "Kopiczko",
  "Jachimczak",
  "Hirsch",
  "Dytrych",
  "Dorna",
  "Bystro\u0144",
  "Worach",
  "Tokaj",
  "Szmagaj",
  "Solnica",
  "Rejmak",
  "Reimann",
  "Pazo\u0142a",
  "Nieradzik",
  "Miechowicz",
  "Langiewicz",
  "Kru\u015b",
  "Kozie\u0144",
  "Kielczyk",
  "Jargi\u0142o",
  "D\u0105bal",
  "Cichos",
  "Sorbian",
  "Ruman",
  "Piotrkowicz",
  "Ozi\u0119b\u0142o",
  "Henke",
  "Czosnyka",
  "Choina",
  "Chabior",
  "Warzybok",
  "Seweryniak",
  "Pyzel",
  "Niewola",
  "Nesterowicz",
  "Liss",
  "Kiepas",
  "Kalista",
  "Demia\u0144czuk",
  "C\u0142apa",
  "B\u0142asik",
  "Berdzik",
  "Be\u0142za",
  "Z\u0142otek",
  "Tonder",
  "Szwaj",
  "Szarzec",
  "Suchora",
  "Sarota",
  "Palica",
  "Matula",
  "Malecha",
  "Magryta",
  "\u0141uckiewicz",
  "Kuster",
  "Stoltman",
  "Siewert",
  "Serwach",
  "Schwarz",
  "Ku\u017ania",
  "Ku\u015bmider",
  "Kurzac",
  "Klisz",
  "Gwardiak",
  "Gotfryd",
  "Deneka",
  "Ciuru\u015b",
  "\u017bmija",
  "Ta\u0142aj",
  "Sobu\u015b",
  "Rajman",
  "Perlik",
  "Kurda",
  "Kosznik",
  "Kaluga",
  "Jaracz",
  "Hanas",
  "Dzwonnik",
  "Ziegert",
  "Szyma",
  "R\u00f3\u017cewicz",
  "Paszkowiak",
  "Ma\u015blach",
  "Lewicz",
  "Heba",
  "Godzwon",
  "Drej",
  "Borak",
  "Adam\u00f3w",
  "Tywoniuk",
  "\u015acieszka",
  "Smal",
  "\u0141abu\u015b",
  "Kominiak",
  "Dietrich",
  "C\u0105ka\u0142a",
  "Budzich",
  "B\u0105bol",
  "Zgo\u0142a",
  "S\u0142adek",
  "Sier\u017cant",
  "Misiurek",
  "Mi\u0105sik",
  "M\u0105drzyk",
  "Kretowicz",
  "Kasznia",
  "Je\u017cyna",
  "Humeniuk",
  "Fiutak",
  "Czerniakiewicz",
  "Bork",
  "\u017byme\u0142ka",
  "Tomalik",
  "Szarpak",
  "So\u0142tan",
  "Maciuszek",
  "Krysta",
  "Grzeszkowiak",
  "Brachman",
  "Zys",
  "Westfal",
  "Waluk",
  "Wac\u0142awiak",
  "Sa\u0142uda",
  "Sabak",
  "Niedojad\u0142o",
  "Nazarko",
  "Murat",
  "Majzner",
  "Ludwin",
  "Kubaczyk",
  "Kielich",
  "Doliwa",
  "Dej",
  "Chuchla",
  "Bogu\u015b",
  "Bobik",
  "Zadworny",
  "W\u00f3js",
  "Tyma",
  "Sztuczka",
  "Strz\u0105da\u0142a",
  "Sowa\u0142a",
  "Omiotek",
  "Ole\u015bkiewicz",
  "Morawiak",
  "Kwapisiewicz",
  "Krokosz",
  "Hajder",
  "Garczyk",
  "Burdach",
  "Zwi\u0105zek",
  "Wojczuk",
  "Stanclik",
  "Piekart",
  "Mielke",
  "Machowicz",
  "Kozieja",
  "Kazir\u00f3d",
  "Ga\u015b",
  "Garbaciak",
  "Chatys",
  "Bzd\u0119ga",
  "Bartoszczyk",
  "Zdonek",
  "Wi\u0119c\u0142awek",
  "Wielgo",
  "Steuer",
  "Star\u0119ga",
  "Sakwa",
  "Orpel",
  "Kobel",
  "Golonko",
  "Stark",
  "Socz\u00f3wka",
  "Nickel",
  "Kupaj",
  "Kolman",
  "Kieca",
  "Kamyk",
  "Je\u017cyk",
  "Glica",
  "Gasz",
  "Gamrat",
  "Franiak",
  "Bacik",
  "Andrukiewicz",
  "Troka",
  "Siwka",
  "Odrzywo\u0142ek",
  "Nurkiewicz",
  "Kozubal",
  "Kott",
  "G\u0142owienka",
  "Doroszuk",
  "Cogiel",
  "Cheba",
  "Ba\u015b",
  "Andreasik",
  "Wenzel",
  "Szumna",
  "Ros\u0142o\u0144",
  "Og\u0142aza",
  "Mik\u0142aszewicz",
  "Kubieniec",
  "J\u0119dral",
  "Bieniak",
  "Wons",
  "W\u0142adyka",
  "Rolak",
  "Prejs",
  "P\u0142ocharczyk",
  "Ostr\u0119ga",
  "\u0141\u0119gowik",
  "Ludwik",
  "Kopik",
  "Kleinschmidt",
  "Karczmarek",
  "G\u0142adka",
  "Czylok",
  "Wawrzynkiewicz"
)

person_male_last_names_pl_pl = c(
  "Kowalski",
  "Wi\u015bniewski",
  "D\u0105browski",
  "Lewandowski",
  "W\u00f3jcik",
  "Kami\u0144ski",
  "Kowalczyk",
  "Zieli\u0144ski",
  "Szyma\u0144ski",
  "Wo\u017aniak",
  "Koz\u0142owski",
  "Jankowski",
  "Wojciechowski",
  "Kwiatkowski",
  "Kaczmarek",
  "Mazur",
  "Krawczyk",
  "Piotrowski",
  "Grabowski",
  "Nowakowski",
  "Paw\u0142owski",
  "Michalski",
  "Nowicki",
  "Adamczyk",
  "Dudek",
  "Zaj\u0105c",
  "Wieczorek",
  "Jab\u0142o\u0144ski",
  "Kr\u00f3l",
  "Majewski",
  "Olszewski",
  "Jaworski",
  "Wr\u00f3bel",
  "Malinowski",
  "Pawlak",
  "Witkowski",
  "Walczak",
  "St\u0119pie\u0144",
  "G\u00f3rski",
  "Rutkowski",
  "Michalak",
  "Sikora",
  "Ostrowski",
  "Baran",
  "Duda",
  "Szewczyk",
  "Tomaszewski",
  "Pietrzak",
  "Marciniak",
  "Wr\u00f3blewski",
  "Zalewski",
  "Jakubowski",
  "Jasi\u0144ski",
  "Zawadzki",
  "Sadowski",
  "B\u0105k",
  "Chmielewski",
  "W\u0142odarczyk",
  "Borkowski",
  "Czarnecki",
  "Sawicki",
  "Soko\u0142owski",
  "Urba\u0144ski",
  "Kubiak",
  "Maciejewski",
  "Szczepa\u0144ski",
  "Kucharski",
  "Wilk",
  "Kalinowski",
  "Lis",
  "Mazurek",
  "Wysocki",
  "Adamski",
  "Ka\u017amierczak",
  "Wasilewski",
  "Sobczak",
  "Czerwi\u0144ski",
  "Andrzejewski",
  "Cie\u015blak",
  "G\u0142owacki",
  "Zakrzewski",
  "Ko\u0142odziej",
  "Sikorski",
  "Krajewski",
  "Gajewski",
  "Szymczak",
  "Szulc",
  "Baranowski",
  "Laskowski",
  "Brzezi\u0144ski",
  "Makowski",
  "Zi\u00f3\u0142kowski",
  "Przybylski",
  "Doma\u0144ski",
  "Nowacki",
  "Borowski",
  "B\u0142aszczyk",
  "Chojnacki",
  "Ciesielski",
  "Mr\u00f3z",
  "Szczepaniak",
  "Weso\u0142owski",
  "G\u00f3recki",
  "Krupa",
  "Kaczmarczyk",
  "Leszczy\u0144ski",
  "Lipi\u0144ski",
  "Kowalewski",
  "Urbaniak",
  "Kozak",
  "Kania",
  "Miko\u0142ajczyk",
  "Czajkowski",
  "Mucha",
  "Tomczak",
  "Kozio\u0142",
  "Markowski",
  "Kowalik",
  "Nawrocki",
  "Brzozowski",
  "Janik",
  "Musia\u0142",
  "Wawrzyniak",
  "Markiewicz",
  "Or\u0142owski",
  "Tomczyk",
  "Jarosz",
  "Ko\u0142odziejczyk",
  "Kurek",
  "Kope\u0107",
  "\u017bak",
  "Wolski",
  "\u0141uczak",
  "Dziedzic",
  "Kot",
  "Stasiak",
  "Stankiewicz",
  "Pi\u0105tek",
  "J\u00f3\u017awiak",
  "Urban",
  "Dobrowolski",
  "Pawlik",
  "Kruk",
  "Domaga\u0142a",
  "Piasecki",
  "Wierzbicki",
  "Karpi\u0144ski",
  "Jastrz\u0119bski",
  "Polak",
  "Zi\u0119ba",
  "Janicki",
  "W\u00f3jtowicz",
  "Stefa\u0144ski",
  "Sosnowski",
  "Bednarek",
  "Majchrzak",
  "Bielecki",
  "Ma\u0142ecki",
  "Maj",
  "Sowa",
  "Milewski",
  "Gajda",
  "Klimek",
  "Olejniczak",
  "Ratajczak",
  "Romanowski",
  "Matuszewski",
  "\u015aliwi\u0144ski",
  "Madej",
  "Kasprzak",
  "Wilczy\u0144ski",
  "Grzelak",
  "Socha",
  "Czajka",
  "Marek",
  "Kowal",
  "Bednarczyk",
  "Skiba",
  "Wrona",
  "Owczarek",
  "Marcinkowski",
  "Matusiak",
  "Orzechowski",
  "Sobolewski",
  "K\u0119dzierski",
  "Kurowski",
  "Rogowski",
  "Olejnik",
  "D\u0119bski",
  "Bara\u0144ski",
  "Skowro\u0144ski",
  "Mazurkiewicz",
  "Paj\u0105k",
  "Czech",
  "Janiszewski",
  "Bednarski",
  "\u0141ukasik",
  "Chrzanowski",
  "Bukowski",
  "Le\u015bniak"
)

person_prefixes_pl_pl = c('pan', 'pani')

person_first_names_pl_pl = c(person_first_names_male_pl_pl,
                             person_first_names_female_pl_pl)

person_pl_pl <- list(
  first_names = person_first_names_pl_pl,
  first_names_female = person_first_names_female_pl_pl,
  first_names_male = person_first_names_male_pl_pl,
  last_names = person_unisex_last_names_pl_pl,
  last_names_male = person_male_last_names_pl_pl,
  prefixes = person_prefixes_pl_pl
)


# @classmethod
# def last_name(cls):
#   return cls.random_element(cls.unisex_last_names)
